==> macro-command-1.0.0.tgz: package/test/core/commandContextTests.js <==
/**
 * Created by ruckola on 6-12-16.
 */

var assert = require("chai").assert;
var expect = require("chai").expect;
var CommandContext = require("../../bin/core/commandContext");

describe("Test suite for the CommandContext class: ", function () {

    afterEach(function(){
        delete ctxt;
    })

    it('"request" parameter of the "constructor" should be optional', function () {
        ctxt = new CommandContext();
    });

    it('"constructor" should receive a(ny) request object without error', function () {
        var request = {};
        ctxt = new CommandContext(request);
    });

    it('"constructor" cannot change the type of the private property "parameters"'+
        'thus any argument must be of type "object"', function () {

        // trying to assign a fake request of type string to property parameters
        // (which must be and stay of type object)
        // should not be accepted! 
        var request = "Try to fool me"; 
        ctxt = new CommandContext(request);
        expect(ctxt.parameters).to.eql({action:'default', returnMode: 0});
    });

    it('If "constructor" recognizes an incoming request as of type "Object",\n' +
        '      it will be assigned to private property "parameters.request"', function () {
        var request = {foo : "bar"};
        ctxt = new CommandContext(request);
        assert.equal(ctxt.parameters.request['foo'],"bar");
    });

    it('"addParameter" should add a key-value-pair without error', function () {
        ctxt = new CommandContext();
        ctxt.addParameter("testKey","testValue");
    });

    it('"get" should return value {"foo":"bar"} without error', function () {
        var request = {foo : "bar"};
        ctxt = new CommandContext(request);
        assert.equal(ctxt.get("request").foo,"bar");
    });
});

==> macro-command-1.0.11.tgz: package/test/core/commandContextTests.js <==
/**
 * Created by ruckola on 6-12-16.
 */


var assert = require("chai").assert;
var expect = require("chai").expect;
var CommandContext = require("../../bin/core/commandContext");

describe("Test suite for the CommandContext class: ", function () {

    afterEach(function(){
        delete ctxt;
    })

    it('"request" parameter of the "constructor" should be optional', function () {
        ctxt = new CommandContext();
    });

    it('"constructor" should receive a(ny) request object without error', function () {
        var request = {};
        ctxt = new CommandContext(request);
    });

    it("check if the constructor sets default values as expected",function(){
        var request = "This fake request should not be assigend"; 
        ctxt = new CommandContext(request);
        expect(ctxt.parameters).to.eql(
            {action: "macro", macroID: false, request: false, userCommandsRootDir: false,
             userConfigFile: false, userConfiguration: false, userHelperDir: false});
    })

   it('If "constructor" recognizes an incoming request as of type "Object",\n' +
        '      it will be assigned to private property "parameters.request"', function () {
        var request = {foo : "bar"};
        ctxt = new CommandContext(request);
        assert.equal(ctxt.parameters.request['foo'],"bar");
    });

    it('"addParameter" should add a key-value-pair without error', function () {
        ctxt = new CommandContext();
        ctxt.addParameter("testKey","testValue");
    });

    it('"get" should return value {"foo":"bar"} without error', function () {
        var request = {foo : "bar"};
        ctxt = new CommandContext(request);
        assert.equal(ctxt.get("request").foo,"bar");
    });
});
